/*
 *  dice - DESCRIPTION OF PACKAGE
 *  Copyright (C) 2003 RossLodge
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  The author of this program grants you the ability to use this code
 *  in conjunction with code that is covered under the Open Gaming License
 *
 *  UnaryRoll.java
 *
 *  Created on Oct 18, 2003, 1:34:56 PM
 */
package com.electronicmuse.djep.function;
 
import java.util.Stack;

import com.electronicmuse.djep.ParseException;


/**
 * <p>This class is an extension of the Roll class for unary roll expressions.  It
 * assumes that if a user wants to roll a single die, the user may enter <code>dY</code>
 * instead of <code>XdY</code>; this class evaluates <code>dX</code> as <code>1dX</code>.</p>
 * 
 * @author Ross M. Lodge
 */
public class UnaryRoll extends Roll
{
	/**
	 * 
	 * <p>The default (and only) constructor.  Sets the number
	 * of parameters for the JEP package, and calls the super implementation.</p>
	 */
	public UnaryRoll()
	{
		super();
		numberOfParameters = 1;
	}

	/**
	 * <p>The run command for the JEP framework.  This receives the arguments
	 * to the operator as a stack, pops off the one it needs, does type checking,
	 * rolls the dice on the randomizer, and pushes the result back onto the stack.
	 * Logging is performed if it is turned on.</p>
	 * 
	 * @see org.nfunk.jep.function.PostfixMathCommandI#run(java.util.Stack)
	 */
	public void run(Stack inStack) throws ParseException
	{
		// check the stack
		checkStack(inStack);

		// get the parameter from the stack
		Object faces = inStack.pop();

		// check whether the argument is of the right type
		if (faces instanceof Double)
		{
			// calculate the result
			double dFaces = ((Double)faces).doubleValue();
			if (dFaces > Integer.MAX_VALUE)
			{
				throw new ParseException("Values greater than "
						+ Integer.MAX_VALUE
						+ " not allowed.");
			}
			int iRolls = 1;
			int iFaces = (int)Math.round(((Double)faces).doubleValue());
			double result = 0;
			result = performRoll(iRolls, iFaces);
			// push the result on the inStack
			inStack.push(new Double(result));
		}
		else
		{
			throw new ParseException("Invalid parameter type");
		}
	}
	

}
